==> nextcloud-app-mail-4.3.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/et_EE.js <==
OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Lõimitud e-kiri %s",
    "Important mail" : "Oluline e-kiri",
    "No message found yet" : "Ei leidu veel ühtegi kirja",
    "Set up an account" : "Seadista kasutajakonto",
    "Unread mail" : "Lugemata kirjad",
    "Important" : "Tähtis",
    "Work" : "Töö",
    "Personal" : "Isiklik",
    "To Do" : "Tegemiseks",
    "Later" : "Hiljem",
    "Mail" : "Kirjad",
    "Connecting" : "Ühendamine",
    "Save" : "Salvesta",
    "Connect" : "Ühenda",
    "Name" : "Nimi",
    "Mail address" : "E-posti aadress",
    "Password" : "Parool",
    "IMAP Host" : "IMAP server",
    "None" : "Pole",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP port",
    "IMAP User" : "IMAP kasutaja",
    "IMAP Password" : "IMAP parool",
    "SMTP Host" : "SMTP server",
    "SMTP Port" : "SMTP port",
    "SMTP User" : "SMTP kasutaja",
    "SMTP Password" : "SMTP parool",
    "Aliases" : "Aliased",
    "Signature" : "Allkiri",
    "Go to Sieve settings" : "Ava Sieve seadistused",
    "Filters" : "Filtrid",
    "Sieve script editor" : "Sieve skriptikoostaja",
    "Sieve server" : "Sieve server",
    "Go back" : "Mine tagasi",
    "Email address" : "E-posti aadress",
    "Cancel" : "Loobu",
    "Accounts" : "Kasutajakontod",
    "General" : "Üldine",
    "Layout" : "Välimus",
    "List" : "Nimekiri",
    "Register" : "Registreeru",
    "About" : "Rakenduse teave",
    "Keyboard shortcuts" : "Klaviatuuri otseteed",
    "Archive" : "Arhiiv",
    "Delete" : "Kustuta",
    "Search" : "Otsi",
    "Send" : "Saada",
    "Refresh" : "Värskenda",
    "From" : "Saatja",
    "To" : "Saaja",
    "Subject" : "Teema",
    "Enter a date" : "Sisesta kuupäev",
    "Choose" : "Vali",
    "Choose a file to add as attachment" : "Vali fail, mida manustada",
    "_{count} attachment_::_{count} attachments_" : ["{count} manus","{count} manust"],
    "Confirm" : "Kinnita",
    "Favorite" : "Lemmik",
    "Read" : "Lugemine",
    "Edit tags" : "Muuda silte",
    "More actions" : "Täiendavad tegevused",
    "Back" : "Tagasi",
    "Create event" : "Lisa sündmus",
    "Create task" : "Loo ülesanne",
    "_Mark {number} read_::_Mark {number} read_" : ["Märgi {number} loetuks","Märgi {number} loetuks"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Märgi {number} mitteloetuks","Märgi {number} mitteloetuks"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Märgi {number} oluliseks","Märgi {number} oluliseks"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Märgi {number} mitteoluliseks","Märgi {number} mitteoluliseks"],
    "_Favorite {number}_::_Favorite {number}_" : ["Lisa {number} kiri lemmikuks","Lisa {number} kirja lemmikuks"],
    "_Unselect {number}_::_Unselect {number}_" : ["Eemalda {number} kiri lemmikute seast","Eemalda {number} kirja lemmikute seast"],
    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Märgi {number} kiri rämpspostiks","Märgi {number} kirja rämpspostiks"],
    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["Eemalda {number}-lt kirjalt rämpsposti märge","Eemalda {number}-lt kirjalt rämpsposti märge"],
    "_Edit tags for {number}_::_Edit tags for {number}_" : ["Muuda {number} kirja silte","Muuda {number} kirja silte"],
    "_Move {number} thread_::_Move {number} threads_" : ["Teisalda {number} jutulõng","Teisalda {number} jutulõnga"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Edasta {number} kiri manusena","Edasta {number} kirja manusena"],
    "All day" : "Kogu päev",
    "Description" : "Kirjeldus",
    "Create" : "Loo",
    "Select" : "Vali",
    "Comment" : "Kommentaar",
    "Accept" : "Nõustu",
    "Decline" : "Keeldu",
    "Remove" : "Eemalda",
    "email" : "e-post",
    "Other" : "Muu",
    "Forward" : "Edasi",
    "Translate" : "Tõlgi",
    "Unnamed" : "Nimeta",
    "Choose a folder to store the attachment in" : "Vali kaust, kuhu manus salvestada",
    "Move" : "Liiguta",
    "Loading …" : "Laadimine ...",
    "Remove account" : "Eemalda konto",
    "Remove {email}" : "Eemalda fail: „{email}“",
    "Quota" : "Kvoot",
    "Saving" : "Salvestamine",
    "Move up" : "Liiguta ülespoole",
    "Move down" : "Liiguta allapoole",
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} lugemata kiri {total}-st kirjast","{unread} lugemata kirja {total}-st kirjast"],
    "Mark all as read" : "Märgi loetuks",
    "Mark all messages of this mailbox as read" : "Märgi kõik selle postkasti kirjad loetuks",
    "Add submailbox" : "Lisa alampostkast",
    "Rename" : "Muuda nime",
    "Move mailbox" : "Teisalda postkast",
    "Repair mailbox" : "Paranda postkasti",
    "Clear cache" : "Tühjenda puhver",
    "New message" : "Uus sõnum",
    "Edit message" : "Muuda sõnumit",
    "Reply" : "Vasta",
    "Your message has no subject. Do you want to send it anyway?" : "Sinu e-kirjal puudub teema. Kas sa kindlasti soovid seda saata?",
    "Retry" : "Proovi uuesti",
    "Sending …" : "Saadan ...",
    "Message" : "Sõnum",
    "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
    "Add" : "Lisa",
    "Show less" : "Näita vähem",
    "Show more" : "Näita rohkem",
    "Clear" : "Tühjenda",
    "Close" : "Sulge",
    "Date" : "Kuupäev",
    "Tags" : "Sildid",
    "Select tags" : "Vali sildid",
    "Last 7 days" : "Viimase 7 päeva jooksul",
    "Custom" : "Kohandatud",
    "Tag already exists" : "Silt on juba olemas",
    "Print" : "Trüki",
    "Not found" : "Ei leidu",
    "Please wait for the message to load" : "Palun oota, kuni e-kirja laadimine on lõppenud",
    "Mark as unread" : "Märgi mitteloetuks",
    "Mark as read" : "Märgi loetuks",
    "Translate message" : "Tõlgi e-kiri",
    "Source language to translate from" : "Tõlke lähtekeel",
    "Translate from" : "Lähtekeel tõlkimisel",
    "Target language to translate into" : "Sihtkeel tõlkimisel",
    "Translate to" : "Tõlke sihtkeel",
    "Translating" : "Tõlkimisel",
    "Copy translated text" : "Kopeeri tõlgitud tekst",
    "Delete action" : "Kustuta tegevus",
    "Operator" : "Operaator",
    "Actions" : "Tegevused",
    "Priority" : "Prioriteet",
    "Reset" : "Lähtesta",
    "Client ID" : "Kliendi ID",
    "Client secret" : "Kliendi salasõna",
    "User" : "Kasutaja",
    "Host" : "Host",
    "Port" : "Port",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Sertifikaadi importimine ei õnnestunud. Palun kontrolli, et privaatvõti vastab sertifikaadile ja ta ei ole salafraasiga krüptitud.",
    "Failed to import the certificate" : "Sertifikaadi importimine ei õnnestunud",
    "S/MIME certificates" : "S/MIME sertifikaadid",
    "Certificate name" : "Sertifikaadi nimi",
    "E-mail address" : "E-posti aadress",
    "Valid until" : "Kehtib kuni",
    "Delete certificate" : "Kustuta sertifikaat",
    "No certificate imported yet" : "Ühtegi sertifikaati pole imporditud",
    "Import certificate" : "Impordi sertifikaat",
    "Import S/MIME certificate" : "Impordi S/MIME sertifikaat",
    "PKCS #12 Certificate" : "PKCS #12 sertifikaat",
    "PEM Certificate" : "PEM sertifikaat",
    "Certificate" : "Sertifikaat",
    "Private key (optional)" : "Privaatvõti (kui vaja)",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Privaatvõtit on vaja vaid siis, kui plaanid selle sertifikaadiga saata allkirjastatud ja krüptitud e-kirju.",
    "Submit" : "Saada",
    "Account connected" : "Konto ühendatud",
    "You can close this window" : "Võid selle akna sulgeda.",
    "Connect your mail account" : "Ühenda oma e-posti kontoga",
    "To add a mail account, please contact your administrator." : "Oma e-posti konto lisamiseks palun võta ühendust oma peakasutajaga.",
    "All" : "Kõik",
    "Drafts" : "Mustandid",
    "Favorites" : "Lemmikud",
    "Priority inbox" : "Olulised kirjad",
    "All inboxes" : "Kõik postkastid",
    "Inbox" : "Postkast",
    "Junk" : "Rämpspost",
    "Sent" : "Saadetud",
    "Trash" : "Prügikast",
    "Error while sharing file" : "Viga faili jagamisel",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Discard changes" : "Hülga muudatused",
    "Discard unsaved changes" : "Loobu salvestamata muutustest",
    "Keep editing message" : "Jätka kirja kirjutamist",
    "Attachments were not copied. Please add them manually." : "Manused pole kopeeritud. Palun lisa nad käsitsi.",
    "Message sent" : "Kiri on saadetud",
    "Could not send message" : "Kirja saatmine ei õnnestu",
    "Message copied to \"Sent\" mailbox" : "Kiri on kopeeritud „Saadetud“ postkasti",
    "Could not copy message to \"Sent\" mailbox" : "Kirja on kopeerimine „Saadetud“ postkasti ei õnnestunud",
    "Error loading message" : "Tõrge kirja laadimisel",
    "Forwarding to %s" : "Edasta %s",
    "Redirect" : "Suunamine",
    "Continue to %s" : "Jätka siit: %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-5.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/et_EE.js <==
OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Lõimitud e-kiri %s",
    "Important mail" : "Oluline e-kiri",
    "No message found yet" : "Ei leidu veel ühtegi kirja",
    "Set up an account" : "Seadista kasutajakonto",
    "Unread mail" : "Lugemata kirjad",
    "Important" : "Tähtis",
    "Work" : "Töö",
    "Personal" : "Isiklik",
    "To Do" : "Tegemiseks",
    "Later" : "Hiljem",
    "Mail" : "Kirjad",
    "Mail Application" : "E-posti rakendus",
    "Mail connection performance" : "E-postiteenuse ühenduse jõudlus",
    "Connecting" : "Ühendamine",
    "Save" : "Salvesta",
    "Connect" : "Ühenda",
    "Name" : "Nimi",
    "Mail address" : "E-posti aadress",
    "Password" : "Parool",
    "IMAP Host" : "IMAP server",
    "None" : "Pole",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP port",
    "IMAP User" : "IMAP kasutaja",
    "IMAP Password" : "IMAP parool",
    "SMTP Host" : "SMTP server",
    "SMTP Port" : "SMTP port",
    "SMTP User" : "SMTP kasutaja",
    "SMTP Password" : "SMTP parool",
    "Aliases" : "Aliased",
    "Signature" : "Allkiri",
    "Go to Sieve settings" : "Ava Sieve seadistused",
    "Filters" : "Filtrid",
    "Sieve script editor" : "Sieve skriptikoostaja",
    "Sieve server" : "Sieve server",
    "Go back" : "Mine tagasi",
    "Email address" : "E-posti aadress",
    "Cancel" : "Loobu",
    "Accounts" : "Kasutajakontod",
    "General" : "Üldine",
    "Layout" : "Välimus",
    "List" : "Nimekiri",
    "Register" : "Registreeru",
    "About" : "Rakenduse teave",
    "Keyboard shortcuts" : "Klaviatuuri otseteed",
    "Archive" : "Arhiiv",
    "Delete" : "Kustuta",
    "Search" : "Otsi",
    "Send" : "Saada",
    "Refresh" : "Värskenda",
    "From" : "Saatja",
    "To" : "Saaja",
    "Subject" : "Teema",
    "Enter a date" : "Sisesta kuupäev",
    "Choose" : "Vali",
    "Choose a file to add as attachment" : "Vali fail, mida manustada",
    "_{count} attachment_::_{count} attachments_" : ["{count} manus","{count} manust"],
    "Confirm" : "Kinnita",
    "Set reminder for later today" : "Lisa meeldetuletus tänaseks hilisemaks ajaks",
    "Set reminder for tomorrow" : "Lisa meeldetuletus homseks",
    "Set reminder for this weekend" : "Lisa meeldetuletus selleks nädalavahetuseks",
    "Set reminder for next week" : "Lisa meeldetuletus järgmiseks nädalaks",
    "This summary was AI generated" : "Koond on loodud tehisaru poolt",
    "Favorite" : "Lemmik",
    "Unread" : "Lugemata",
    "Read" : "Lugemine",
    "Edit tags" : "Muuda silte",
    "More actions" : "Täiendavad tegevused",
    "Back" : "Tagasi",
    "Create event" : "Lisa sündmus",
    "Create task" : "Loo ülesanne",
    "_Mark {number} read_::_Mark {number} read_" : ["Märgi {number} loetuks","Märgi {number} loetuks"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Märgi {number} mitteloetuks","Märgi {number} mitteloetuks"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Märgi {number} oluliseks","Märgi {number} oluliseks"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Märgi {number} mitteoluliseks","Märgi {number} mitteoluliseks"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Eemalda {number} lemmikute seast","Eemalda {number} lemmikute seast"],
    "_Favorite {number}_::_Favorite {number}_" : ["Lisa {number} kiri lemmikuks","Lisa {number} kirja lemmikuks"],
    "_Unselect {number}_::_Unselect {number}_" : ["Eemalda {number} kiri lemmikute seast","Eemalda {number} kirja lemmikute seast"],
    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Märgi {number} kiri rämpspostiks","Märgi {number} kirja rämpspostiks"],
    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["Eemalda {number}-lt kirjalt rämpsposti märge","Eemalda {number}-lt kirjalt rämpsposti märge"],
    "_Edit tags for {number}_::_Edit tags for {number}_" : ["Muuda {number} kirja silte","Muuda {number} kirja silte"],
    "_Move {number} thread_::_Move {number} threads_" : ["Teisalda {number} jutulõng","Teisalda {number} jutulõnga"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Edasta {number} kiri manusena","Edasta {number} kirja manusena"],
    "All day" : "Kogu päev",
    "Description" : "Kirjeldus",
    "Create" : "Loo",
    "Select" : "Vali",
    "Comment" : "Kommentaar",
    "Accept" : "Nõustu",
    "Decline" : "Keeldu",
    "More options" : "Täiendavad valikud",
    "This message has an attached invitation but the invitation dates are in the past" : "Selle kirja manuses on kutse, kuid kutse kuupäevad  on minevikus.",
    "This message has an attached invitation but the invitation does not contain a participant that matches any configured mail account address" : "Selle kirja manuses on kutse, kuid kutses leidub osaleja, kes ei vasta ühelegi seadistatud e-posti aadressile.",
    "Remove" : "Eemalda",
    "email" : "e-post",
    "Other" : "Muu",
    "Forward" : "Edasi",
    "Translate" : "Tõlgi",
    "Unnamed" : "Nimeta",
    "Choose a folder to store the attachment in" : "Vali kaust, kuhu manus salvestada",
    "Move" : "Liiguta",
    "Loading …" : "Laadimine ...",
    "Remove account" : "Eemalda konto",
    "Remove {email}" : "Eemalda fail: „{email}“",
    "Quota" : "Kvoot",
    "Saving" : "Salvestamine",
    "Move up" : "Liiguta ülespoole",
    "Move down" : "Liiguta allapoole",
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} lugemata kiri {total}-st kirjast","{unread} lugemata kirja {total}-st kirjast"],
    "Please wait 10 minutes before repairing again" : "Enne uuesti parandamist palun oota 10 minutit",
    "Mark all as read" : "Märgi loetuks",
    "Mark all messages of this mailbox as read" : "Märgi kõik selle postkasti kirjad loetuks",
    "Add submailbox" : "Lisa alampostkast",
    "Rename" : "Muuda nime",
    "Move mailbox" : "Teisalda postkast",
    "Repair mailbox" : "Paranda postkasti",
    "Clear cache" : "Tühjenda puhver",
    "New message" : "Uus sõnum",
    "Edit message" : "Muuda sõnumit",
    "Reply" : "Vasta",
    "Your message has no subject. Do you want to send it anyway?" : "Sinu e-kirjal puudub teema. Kas sa kindlasti soovid seda saata?",
    "Show recipient details" : "Näita kirjasaaja üksikasju",
    "Hide recipient details" : "Peida kirjasaaja üksikasjad",
    "Retry" : "Proovi uuesti",
    "Sending …" : "Saadan ...",
    "First day" : "Esimene päev",
    "Message" : "Sõnum",
    "This email might be a phishing attempt" : "See e-kiri võib olla üks õngitsuskatse",
    "Hide suspicious links" : "Peida kahtlased lingid",
    "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
    "Add" : "Lisa",
    "Show less" : "Näita vähem",
    "Show more" : "Näita rohkem",
    "Clear" : "Tühjenda",
    "Close" : "Sulge",
    "Date" : "Kuupäev",
    "Tags" : "Sildid",
    "Select tags" : "Vali sildid",
    "Mentions me" : "Mainib mind",
    "Last 7 days" : "Viimase 7 päeva jooksul",
    "Enable sieve filter" : "Lülita sieve filter sisse",
    "Custom" : "Kohandatud",
    "Tag already exists" : "Silt on juba olemas",
    "Print" : "Trüki",
    "Not found" : "Ei leidu",
    "Please wait for the message to load" : "Palun oota, kuni e-kirja laadimine on lõppenud",
    "Mark as unread" : "Märgi mitteloetuks",
    "Mark as read" : "Märgi loetuks",
    "Please select languages to translate to and from" : "Palun vali keeled, mille vahel tahad tõlkida",
    "The message could not be translated" : "E-kirja tõlkimine ei õnnestunud",
    "Translation copied to clipboard" : "Tõlge on kopeeritud lõikelauale",
    "Translation could not be copied" : "Tõlke kopeerimine ei õnnestunud",
    "Translate message" : "Tõlgi e-kiri",
    "Source language to translate from" : "Tõlke lähtekeel",
    "Translate from" : "Lähtekeel tõlkimisel",
    "Target language to translate into" : "Sihtkeel tõlkimisel",
    "Translate to" : "Tõlke sihtkeel",
    "Translating" : "Tõlkimisel",
    "Copy translated text" : "Kopeeri tõlgitud tekst",
    "Untitled event" : "Ilma nimeta sündmus",
    "Delete action" : "Kustuta tegevus",
    "The stop action ends all processing" : "See tegevus lõpetab kogu töötlemise",
    "Delete filter" : "Kustuta filter",
    "Delete mail filter {filterName}?" : "Kas kustutame e-posti filtri „{filterName}“?",
    "Are you sure to delete the mail filter?" : "Kas sa oled kindel, et soovid selle e-postifiltri kustutada?",
    "New filter" : "Uus filter",
    "Filter saved" : "Filter on salvestatud",
    "Could not save filter" : "Filtri salvestamine ei õnnestunud",
    "Filter deleted" : "Filter on kustutatud",
    "Could not delete filter" : "Filtri kustutamine on õnnestunud",
    "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "Halda e-kirjade kaost. Filtrid aitavad sul olulist esile tõsta ja müra eemaldada.",
    "Filter is active" : "Filter on kasutusel",
    "Filter is not active" : "Filter pole kasutusel",
    "Operator" : "Operaator",
    "If all tests pass, then the actions will be executed" : "Kui kõik testid toimivad, siis tegevused käivitatakse",
    "If one test pass, then the actions will be executed" : "Kui üks test toimib, siis tegevused käivitatakse",
    "Delete test" : "Kustuta test",
    "Update mail filter" : "Uuenda e-posti filtrit",
    "Filter name" : "Filtri nimi",
    "Tests" : "Testid",
    "New test" : "Uus test",
    "Actions" : "Tegevused",
    "New action" : "Uus tegevus",
    "Priority" : "Prioriteet",
    "Enable filter" : "Kasuta filtrit",
    "Save filter" : "Salvesta filter",
    "Reset" : "Lähtesta",
    "Client ID" : "Kliendi ID",
    "Client secret" : "Kliendi salasõna",
    "User" : "Kasutaja",
    "Host" : "Host",
    "Port" : "Port",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Sertifikaadi importimine ei õnnestunud. Palun kontrolli, et privaatvõti vastab sertifikaadile ja ta ei ole salafraasiga krüptitud.",
    "Failed to import the certificate" : "Sertifikaadi importimine ei õnnestunud",
    "S/MIME certificates" : "S/MIME sertifikaadid",
    "Certificate name" : "Sertifikaadi nimi",
    "E-mail address" : "E-posti aadress",
    "Valid until" : "Kehtib kuni",
    "Delete certificate" : "Kustuta sertifikaat",
    "No certificate imported yet" : "Ühtegi sertifikaati pole imporditud",
    "Import certificate" : "Impordi sertifikaat",
    "Import S/MIME certificate" : "Impordi S/MIME sertifikaat",
    "PKCS #12 Certificate" : "PKCS #12 sertifikaat",
    "PEM Certificate" : "PEM sertifikaat",
    "Certificate" : "Sertifikaat",
    "Private key (optional)" : "Privaatvõti (kui vaja)",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Privaatvõtit on vaja vaid siis, kui plaanid selle sertifikaadiga saata allkirjastatud ja krüptitud e-kirju.",
    "Submit" : "Saada",
    "Account connected" : "Konto ühendatud",
    "You can close this window" : "Võid selle akna sulgeda.",
    "Connect your mail account" : "Ühenda oma e-posti kontoga",
    "To add a mail account, please contact your administrator." : "Oma e-posti konto lisamiseks palun võta ühendust oma peakasutajaga.",
    "All" : "Kõik",
    "Drafts" : "Mustandid",
    "Favorites" : "Lemmikud",
    "Priority inbox" : "Olulised kirjad",
    "All inboxes" : "Kõik postkastid",
    "Inbox" : "Postkast",
    "Junk" : "Rämpspost",
    "Sent" : "Saadetud",
    "Trash" : "Prügikast",
    "Error while sharing file" : "Viga faili jagamisel",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Discard changes" : "Hülga muudatused",
    "Discard unsaved changes" : "Loobu salvestamata muutustest",
    "Keep editing message" : "Jätka kirja kirjutamist",
    "Attachments were not copied. Please add them manually." : "Manused pole kopeeritud. Palun lisa nad käsitsi.",
    "Message sent" : "Kiri on saadetud",
    "Could not send message" : "Kirja saatmine ei õnnestu",
    "Message copied to \"Sent\" mailbox" : "Kiri on kopeeritud „Saadetud“ postkasti",
    "Could not copy message to \"Sent\" mailbox" : "Kirja on kopeerimine „Saadetud“ postkasti ei õnnestunud",
    "Error loading message" : "Tõrge kirja laadimisel",
    "Forwarding to %s" : "Edasta %s",
    "Redirect" : "Suunamine",
    "Continue to %s" : "Jätka siit: %s",
    "Collapse composer" : "Ahenda kirjutusvaade"
},
"nplurals=2; plural=(n != 1);");
